@@ -1,7 +1,7 @@
 use Pies;
 use Panda::Common;
 use File::Find;
-use File::Mkdir;
+use Shell::Command;
 
 class Panda::Installer does Pies::Installer {
     has $!resources;
@@ -17,13 +17,13 @@ class Panda::Installer does Pies::Installer {
             if 'blib'.IO ~~ :d {
                 for find(dir => 'blib', type => 'file').list -> $i {
                     # .substr(5) to skip 'blib/'
-                    mkdir "$!destdir/{$i.dir.substr(5)}", :p;
+                    mkpath "$!destdir/{$i.dir.substr(5)}";
                     $i.IO.copy("$!destdir/{$i.Str.substr(5)}");
                 }
             }
             if 'bin'.IO ~~ :d {
                 for find(dir => 'bin', type => 'file').list -> $bin {
-                    mkdir "$!destdir/{$bin.dir}", :p;
+                    mkpath "$!destdir/{$bin.dir}";
                     $bin.IO.copy("$!destdir/$bin");
                     "$!destdir/$bin".IO.chmod(0o755);
                 }
@@ -32,7 +32,7 @@ class Panda::Installer does Pies::Installer {
                 for find(dir => 'doc', type => 'file').list -> $doc {
                     my $path = "$!destdir/{$p.name.subst(':', '/', :g)}"
                              ~ "/{$doc.dir}";
-                    mkdir $path, :p;
+                    mkpath $path;
                     $doc.IO.copy("$path/{$doc.name}");
                 }
             }
